==> jts_1.17.0+ds.orig.tar.xz: jts-1.17.0/modules/app/src/main/java/org/locationtech/jtstest/testbuilder/AppStrings.java <==
/*
 * Copyright (c) 2016 Vivid Solutions.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * and Eclipse Distribution License v. 1.0 which accompanies this distribution.
 * The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v20.html
 * and the Eclipse Distribution License is available at
 *
 * http://www.eclipse.org/org/documents/edl-v10.php.
 */

package org.locationtech.jtstest.testbuilder;

public class AppStrings {

  public static final String LABEL_TEST_CASE = "Case";

  public static final String GEOM_LABEL_A = "A";
  public static final String GEOM_LABEL_B = "B";
  
  public static final String TAB_LABEL_LOG = "Log";
  public static final String TAB_LABEL_VALUE = "Value";
  static final String TAB_LABEL_RESULT = "Result";
  static final String TAB_LABEL_INSPECT = "Inspect";
  static final String TAB_LABEL_INPUT = "Input";
  static final String TAB_LABEL_LAYERS = "Layers";
  static final String TAB_LABEL_STATS = "Stats";
  static final String TAB_LABEL_CASES = "Cases";
  public static final Object TAB_LABEL_COMMAND = "Command";

  public static final String TIP_TEXT_ENTRY = "<html>Enter WKT, WKB, GeoJSON, or GML"
      + "<br>Drop a WKT, WKB, GeoJSON, GML or SHP file</html>";
  public static final String TIP_WKT_PANEL_LOAD_GEOMETRY = "Load geometries";
  public static final String TIP_INSPECT_GEOMETRY = "Inspect Geometry";

  static final String TIP_EXTRACT_COMPONENTS = "<html>Extract Components/Segments to Case<br><br>Components = Drag<br>Segments = Ctl-Drag</html>";

  static final String TIP_DELETE_VERTEX_COMPONENT = "<html>Delete Components/Vertices<br><br>Delete Components = Drag<br>Delete Intersecting Components = Ctl-Drag<br>Delete Vertices = Right-Drag</html>";

  static final String TIP_MOVE_VERTEX = "<html>Move/Add/Delete Vertex<br><br>Move = Drag<br>Add = Right-Click<br>Delete = Ctl-Right-Click</html>";

  static final String TIP_PAN = "Pan";
  static final String TIP_ZOOM_TO_FULL_EXTENT = "Zoom To Full Extent";
  static final String TIP_ZOOM_TO_RESULT = "Zoom To Result";
  static final String TIP_ZOOM_TO_B = "Zoom To B";
  static final String TIP_ZOOM_TO_A = "Zoom To A";
  static final String TIP_ZOOM_1_1 = "Zoom 1:1";
  static final String TIP_ZOOM = "<html>Zoom In/Out | Pan<br><br>Zoom In = Left-Btn<br>Zoom Extent = Left-Drag<br>Zoom Out = Right-Btn<br>Pan = Right-Drag | Ctl-Drag</html>";

  static final String TIP_INFO = "Show Info on Geometry, Segment, or Point";

  static final String TIP_DRAW_RECTANGLE = "Draw Rectangle";
  static final String TIP_DRAW_POINT = "Draw Point";
  static final String TIP_DRAW_LINE = "<html>Draw LineString<br><br>Add Pt = Left-Click<br>Stream = Left-Drag</html>";
  static final String TIP_DRAW_POLY = "<html>Draw Polygon<br><br>Add Pt = Left-Click<br>Stream = Left-Drag</html>";


  static final String TIP_EXCHANGE_A_B = "Exchange A & B";

  static final String TIP_CASE_DELETE = "Delete Case";
  static final String TIP_CASE_DUP = "Duplicate Case";
  static final String TIP_CASE_ADD_NEW = "Add New Case";

  static final String TIP_NEXT = "<html>Next Case<br><br>No Zoom = Ctl-Click</html>";
  static final String TIP_PREV = "<html>Previous Case<br><br>No Zoom = Ctl-Click</html>";

  static final String TIP_PASTE_DATA = "Paste from WKT, WKB, or GML";

  static final String TIP_COPY_DATA = "<html>Copy as WKT"
      + "<br>Formatted WKT = Ctl-click"
      + "<br>WKB = Shift-click</html>";

  static final String TIP_EXECUTE = "Compute the result of the function";

  public static final String TIP_SAVE_IMAGE = "<html>Save Image to Clipboard<br>Save Image to File = Ctl-Click</html>";

  public static final String TIP_STYLE_VERTEX_ENABLE = "Show Vertices";
  public static final String TIP_STYLE_LINE_ENABLE = "Show Line";
  public static final String TIP_STYLE_FILL_ENABLE = "Show Fill";

  public static final String TIP_LAYER_CLEAR = "<html>Clear Layer<br>Remove Layer = Ctl-Click</html>";

  public static final String TIP_STYLE_VERTEX_LABEL_ENABLE = "Show vertex labels";


}

==> jts_1.19.0+ds.orig.tar.xz: jts-1.19.0/modules/app/src/main/java/org/locationtech/jtstest/testbuilder/AppStrings.java <==
/*
 * Copyright (c) 2016 Vivid Solutions.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * and Eclipse Distribution License v. 1.0 which accompanies this distribution.
 * The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v20.html
 * and the Eclipse Distribution License is available at
 *
 * http://www.eclipse.org/org/documents/edl-v10.php.
 */

package org.locationtech.jtstest.testbuilder;

public class AppStrings {

  public static final String LABEL_TEST_CASE = "Case";

  public static final String GEOM_LABEL_A = "A";
  public static final String GEOM_LABEL_B = "B";
  
  public static final String TAB_LABEL_LOG = "Log";
  public static final String TAB_LABEL_VALUE = "Value";
  static final String TAB_LABEL_RESULT = "Result";
  static final String TAB_LABEL_INSPECT = "Inspect";
  static final String TAB_LABEL_INPUT = "Input";
  static final String TAB_LABEL_LAYERS = "Layers";
  static final String TAB_LABEL_STATS = "Stats";
  static final String TAB_LABEL_CASES = "Cases";
  public static final Object TAB_LABEL_COMMAND = "Command";

  public static final String TIP_TEXT_ENTRY = "<html>Enter WKT, WKB, GeoJSON, or GML"
      + "<br>Drop a WKT, WKB, GeoJSON, GML or SHP file</html>";
  public static final String TIP_WKT_PANEL_LOAD_GEOMETRY = "Load geometries";
  public static final String TIP_INSPECT_GEOMETRY = "Inspect Geometry";

  static final String TIP_EXTRACT_COMPONENTS = "<html>Extract Components/Segments to Case<br><br>Components = Drag<br>Segments = Ctl-Drag</html>";

  static final String TIP_DELETE_VERTEX_COMPONENT = "<html>Delete Components/Vertices<br><br>Delete Components = Drag<br>Delete Intersecting Components = Ctl-Drag<br>Delete Vertices = Right-Drag</html>";

  static final String TIP_MOVE_VERTEX = "<html>Move/Add/Delete Vertex<br><br>Move = Drag<br>Add = Right-Click<br>Delete = Ctl-Right-Click</html>";
  static final String TIP_MOVE = "<html>Move<br><br>Geometry = Drag<br>Component = Ctl-Drag<br></html>";

  static final String TIP_PAN = "Pan";
  static final String TIP_ZOOM_TO_FULL_EXTENT = "Zoom To Full Extent";
  static final String TIP_ZOOM_TO_RESULT = "Zoom To Result";
  static final String TIP_ZOOM_TO_B = "Zoom To B";
  static final String TIP_ZOOM_TO_A = "Zoom To A";
  static final String TIP_ZOOM_1_1 = "Zoom 1:1";
  static final String TIP_ZOOM = "<html>Zoom In/Out | Pan<br><br>Zoom In = Left-Btn<br>Zoom Extent = Left-Drag<br>Zoom Out = Right-Btn<br>Pan = Right-Drag | Ctl-Drag</html>";

  static final String TIP_INFO = "Show Info on Geometry, Segment, or Point";

  static final String TIP_DRAW_RECTANGLE = "Draw Rectangle";
  static final String TIP_DRAW_POINT = "Draw Point";
  static final String TIP_DRAW_LINE = "<html>Draw LineString<br><br>Add Pt = Left-Click<br>Stream = Left-Drag</html>";
  static final String TIP_DRAW_POLY = "<html>Draw Polygon<br><br>Add Pt = Left-Click<br>Stream = Left-Drag</html>";


  static final String TIP_EXCHANGE_A_B = "Exchange A & B";

  static final String TIP_CASE_DELETE = "Delete Case";
  static final String TIP_CASE_DUP = "Duplicate Case";
  static final String TIP_CASE_ADD_NEW = "Add New Case";

  static final String TIP_NEXT = "<html>Next Case<br><br>No Zoom = Ctl-Click</html>";
  static final String TIP_PREV = "<html>Previous Case<br><br>No Zoom = Ctl-Click</html>";

  static final String TIP_PASTE_DATA = "Paste from WKT, WKB, or GML";

  static final String TIP_COPY_DATA = "<html>Copy as WKT"
      + "<br>Formatted WKT = Ctl-click"
      + "<br>WKB = Shift-click</html>";

  static final String TIP_EXECUTE = "Compute the result of the function";

  public static final String TIP_SAVE_IMAGE = "<html>Save Image to Clipboard<br>Save Image to File = Ctl-Click</html>";

  public static final String TIP_STYLE_VERTEX_ENABLE = "Show Vertices";
  public static final String TIP_STYLE_LINE_ENABLE = "Show Line";
  public static final String TIP_STYLE_FILL_ENABLE = "Show Fill";

  public static final String TIP_LAYER_CLEAR = "<html>Clear Layer<br>Remove Layer = Ctl-Click</html>";

  public static final String TIP_STYLE_VERTEX_LABEL_ENABLE = "Show vertex labels";

  public static final String TIP_STYLE_PALETTE = "<html>Palette type used for Lines or Fills.<br>Layer color determines base hue and lightness</html>  ";

  public static final String TIP_STYLE_SYMBOL = "Vertex Symbol";

  public static final String TIP_STYLE_SHIFT = "Shift layer display";

  public static final String TIP_ALLOW_INVERTED_RINGS = "Allow valid inverted shells and exverted holes";




}
